# svt-text
svt-text is an unofficial terminal viewer for SVT Text

## Example Usage
svt-text 100-105 202 300-303 401

## Installation
pip3 install svt-text

## Screenshots

![Page 100](/100.png?raw=true "Page 100")

![Page 401](/401.png?raw=true "Page 401")


## License

The source code is released under the AGPL license, but the tiles are not.
